@@ -18,7 +18,13 @@ except ImportError:
     from urllib.parse import unquote as urlunquote  # noqa: F401
 
 try:  # pragma no cover
-    from collections import OrderedDict
+    import xmltodict
+    _xml_to_dict_version = [int(x) for x in xmltodict.__version__.split('.')]
+    # on xmltodict >= 0.13 it returns a dict
+    if _xml_to_dict_version[0] == 0 and _xml_to_dict_version[1] >= 13:
+        OrderedDict = dict
+    else:
+        from collections import OrderedDict
 except ImportError:  # pragma no cover
     try:
         from ordereddict import OrderedDict
