@@ -55,6 +55,7 @@ class RTCClient(RTCBase):
                  url,
                  username,
                  password,
+                 email=None,
                  proxies=None,
                  searchpath=None,
                  ends_with_jazz=True,
@@ -68,6 +69,7 @@ class RTCClient(RTCBase):
 
         self.username = username
         self.password = password
+        self.email = email
         self.proxies = proxies
         self.verify = verify
         self.old_rtc_authentication = old_rtc_authentication
@@ -490,15 +492,10 @@ class RTCClient(RTCBase):
                                          returned_properties=rp,
                                          filter_rule=filter_rule)
 
-    def getOwnedBy(self, email, projectarea_id=None, projectarea_name=None):
-
-        if not isinstance(email, six.string_types) or "@" not in email:
-            excp_msg = "Please specify a valid email address name"
-            self.log.error(excp_msg)
-            raise exception.BadValue(excp_msg)
+    def getOwnedBy(self, username, projectarea_id=None, projectarea_name=None):
 
         parse_result = urlparse.urlparse(self.url)
-        new_path = "/".join(["/jts/users", urlquote(email)])
+        new_path = "/".join(["/jts/users", urlquote(username)])
         new_parse_result = urlparse.ParseResult(scheme=parse_result.scheme,
                                                 netloc=parse_result.netloc,
                                                 path=new_path,
@@ -1039,7 +1036,8 @@ class RTCClient(RTCBase):
                      projectarea_id=None,
                      projectarea_name=None,
                      returned_properties=None,
-                     archived=False):
+                     archived=False,
+                     skip_full_attributes=True):
         """Get all :class:`rtcclient.workitem.Workitem` objects by
         project area id or name
 
@@ -1086,11 +1084,13 @@ class RTCClient(RTCBase):
 
         rp = self._validate_returned_properties(returned_properties)
         for projarea_id in projectarea_ids:
-            workitems = self._get_paged_resources("Workitem",
-                                                  projectarea_id=projarea_id,
-                                                  page_size="100",
-                                                  returned_properties=rp,
-                                                  archived=archived)
+            workitems = self._get_paged_resources(
+                "Workitem",
+                projectarea_id=projarea_id,
+                page_size="100",
+                returned_properties=rp,
+                archived=archived,
+                skip_full_attributes=skip_full_attributes)
             if workitems is not None:
                 workitems_list.extend(workitems)
 
@@ -1345,7 +1345,8 @@ class RTCClient(RTCBase):
                              page_size="100",
                              archived=False,
                              returned_properties=None,
-                             filter_rule=None):
+                             filter_rule=None,
+                             skip_full_attributes=True):
 
         self.log.debug(
             "Start to fetch all %ss with [ProjectArea ID: %s] "
@@ -1483,6 +1484,7 @@ class RTCClient(RTCBase):
         pa_url = ("/".join([self.url, "oslc/projectareas", projectarea_id])
                   if projectarea_id else None)
 
+        self.skip_full_attributes = skip_full_attributes
         resp = self.get(resource_url,
                         verify=self.verify,
                         proxies=self.proxies,
@@ -1509,11 +1511,13 @@ class RTCClient(RTCBase):
 
             # for the last single entry
             if isinstance(entries, OrderedDict):
-                resource = self._handle_resource_entry(resource_name,
-                                                       entries,
-                                                       projectarea_url=pa_url,
-                                                       archived=archived,
-                                                       filter_rule=filter_rule)
+                resource = self._handle_resource_entry(
+                    resource_name,
+                    entries,
+                    projectarea_url=pa_url,
+                    archived=archived,
+                    filter_rule=filter_rule,
+                    skip_full_attributes=skip_full_attributes)
                 if resource is not None:
                     resources_list.append(resource)
                 break
@@ -1526,7 +1530,8 @@ class RTCClient(RTCBase):
                             None,
                             p.starmap(self._handle_resource_entry,
                                       [(resource_name, entry, pa_url, archived,
-                                        filter_rule) for entry in entries]))))
+                                        filter_rule, skip_full_attributes)
+                                       for entry in entries]))))
 
             # find the next page
             url_next = raw_data.get('oslc_cm:Collection').get('@oslc_cm:next')
@@ -1554,7 +1559,8 @@ class RTCClient(RTCBase):
                                entry,
                                projectarea_url=None,
                                archived=False,
-                               filter_rule=None):
+                               filter_rule=None,
+                               skip_full_attributes=True):
         """
         :param filter_rule: a list of filter rules
             e.g. filter_rule = [("dc:creator", "@rdf:resource",
@@ -1610,7 +1616,10 @@ class RTCClient(RTCBase):
         else:
             resource_url = entry.get("@rdf:resource")
 
-        resource = resource_cls(resource_url, self, raw_data=entry)
+        resource = resource_cls(resource_url,
+                                self,
+                                raw_data=entry,
+                                skip_full_attributes=skip_full_attributes)
         return resource
 
     def queryWorkitems(self,
