@@ -27,9 +27,20 @@ class Workitem(FieldBase):
 
     OSLC_CR_RDF = "application/rdf+xml"
 
-    def __init__(self, url, rtc_obj, workitem_id=None, raw_data=None, **kwargs):
+    def __init__(self,
+                 url,
+                 rtc_obj,
+                 workitem_id=None,
+                 raw_data=None,
+                 skip_full_attributes=True,
+                 **kwargs):
         self.identifier = workitem_id
-        FieldBase.__init__(self, url, rtc_obj, raw_data, **kwargs)
+        FieldBase.__init__(self,
+                           url,
+                           rtc_obj,
+                           raw_data,
+                           skip_full_attributes=skip_full_attributes,
+                           **kwargs)
         if self.identifier is None:
             self.identifier = self.url.split("/")[-1]
 
@@ -253,12 +264,15 @@ class Workitem(FieldBase):
         raw_data = xmltodict.parse(resp.content)
         return headers, raw_data
 
-    def _add_subscriber(self, email, raw_data):
+    def _check_email_field(self, email):
         if not isinstance(email, six.string_types) or "@" not in email:
             excp_msg = "Please specify a valid email address name: %s" % email
             self.log.error(excp_msg)
             raise exception.BadValue(excp_msg)
 
+    def _add_subscriber(self, email, raw_data):
+        self._check_email_field(email)
+
         existed_flag = False
         new_subscriber = self.rtc_obj.getOwnedBy(email)
         new_sub = OrderedDict()
@@ -293,10 +307,7 @@ class Workitem(FieldBase):
         return existed_flag, raw_data
 
     def _remove_subscriber(self, email, raw_data):
-        if not isinstance(email, six.string_types) or "@" not in email:
-            excp_msg = "Please specify a valid email address name: %s" % email
-            self.log.error(excp_msg)
-            raise exception.BadValue(excp_msg)
+        self._check_email_field(email)
 
         missing_flag = True
         del_sub = self.rtc_obj.getOwnedBy(email)
