@@ -734,14 +734,6 @@ class TestRTCClient:
             assert member == member1
             assert member.email == "tester1@email.com"
 
-        # test invalid emails
-        invalid_emails = [
-            None, "", u"", False, True, "test%40email.com", u"test%40email.com"
-        ]
-        for invalid_email in invalid_emails:
-            with pytest.raises(BadValue):
-                myrtcclient.getOwnedBy(invalid_email)
-
     @pytest.fixture
     def mock_get_plannedfors(self, mocker):
         mocked_get = mocker.patch("requests.get")
